@@ -1,9 +1,5 @@
 import os
 import numpy as np
-import sample 
-import monochromator
-import kidney 
-import macsdata
 import shutil
 import copy
 import subprocess
